@@ -10,6 +10,7 @@ import sys
 import time
 import typing
 from email.utils import formatdate
+from ipaddress import IPv6Address, ip_address
 
 import click
 
@@ -24,6 +25,8 @@ from uvicorn.config import (
     SSL_PROTOCOL_VERSION,
     WS_PROTOCOLS,
     Config,
+    _get_server_start_message,
+    _IPKind,
 )
 from uvicorn.supervisors import ChangeReload, Multiprocess
 
@@ -227,6 +230,13 @@ def print_version(ctx, param, value):
     help="SSL certificate file",
     show_default=True,
 )
+@click.option(
+    "--ssl-keyfile-password",
+    type=str,
+    default=None,
+    help="SSL keyfile password",
+    show_default=True,
+)
 @click.option(
     "--ssl-version",
     type=int,
@@ -306,6 +316,7 @@ def main(
     timeout_keep_alive: int,
     ssl_keyfile: str,
     ssl_certfile: str,
+    ssl_keyfile_password: str,
     ssl_version: int,
     ssl_cert_reqs: int,
     ssl_ca_certs: str,
@@ -345,11 +356,12 @@ def main(
         "timeout_keep_alive": timeout_keep_alive,
         "ssl_keyfile": ssl_keyfile,
         "ssl_certfile": ssl_certfile,
+        "ssl_keyfile_password": ssl_keyfile_password,
         "ssl_version": ssl_version,
         "ssl_cert_reqs": ssl_cert_reqs,
         "ssl_ca_certs": ssl_ca_certs,
         "ssl_ciphers": ssl_ciphers,
-        "headers": list([header.split(":") for header in headers]),
+        "headers": list([header.split(":", 1) for header in headers]),
         "use_colors": use_colors,
     }
     run(**kwargs)
@@ -452,8 +464,19 @@ class Server:
         if sockets is not None:
             # Explicitly passed a list of open sockets.
             # We use this when the server is run from a Gunicorn worker.
+
+            def _share_socket(sock: socket) -> socket:
+                # Windows requires the socket be explicitly shared across
+                # multiple workers (processes).
+                from socket import fromshare  # type: ignore
+
+                sock_data = sock.share(os.getpid())  # type: ignore
+                return fromshare(sock_data)
+
             self.servers = []
             for sock in sockets:
+                if config.workers > 1 and platform.system() == "Windows":
+                    sock = _share_socket(sock)
                 server = await loop.create_server(
                     create_protocol, sock=sock, ssl=config.ssl, backlog=config.backlog
                 )
@@ -500,12 +523,11 @@ class Server:
             if port == 0:
                 port = server.sockets[0].getsockname()[1]
             protocol_name = "https" if config.ssl else "http"
-            message = "Uvicorn running on %s://%s:%d (Press CTRL+C to quit)"
-            color_message = (
-                "Uvicorn running on "
-                + click.style("%s://%s:%d", bold=True)
-                + " (Press CTRL+C to quit)"
-            )
+            if isinstance(ip_address(config.host), IPv6Address):
+                message, color_message = _get_server_start_message(_IPKind.IPv6)
+            else:
+                message, color_message = _get_server_start_message(_IPKind.IPv4)
+
             logger.info(
                 message,
                 protocol_name,
